Package: sd2R
Type: Package
Title: Stable Diffusion Image Generation
Version: 0.1.9
Authors@R: c(
    person("Yuri", "Baramykov",
        email = "lbsbmsu@mail.ru",
        role = c("aut", "cre")),
    person("Georgi", "Gerganov",
        role = c("ctb", "cph"),
        comment = "Author of the GGML library"),
    person("leejet",
        role = c("ctb", "cph"),
        comment = "Author of stable-diffusion.cpp"),
    person("stduhpf",
        role = "ctb",
        comment = "Core contributor to stable-diffusion.cpp"),
    person("Green-Sky",
        role = "ctb",
        comment = "Contributor to stable-diffusion.cpp"),
    person("wbruna",
        role = "ctb",
        comment = "Contributor to stable-diffusion.cpp"),
    person("akleine",
        role = "ctb",
        comment = "Contributor to stable-diffusion.cpp"),
    person("Martin", "Raiber",
        role = "cph",
        comment = "Copyright holder in miniz.h"),
    person("Rich", "Geldreich",
        role = "cph",
        comment = "Author of miniz.h"),
    person("RAD Game Tools",
        role = "cph",
        comment = "Copyright holder in miniz.h"),
    person("Valve Software",
        role = "cph",
        comment = "Copyright holder in miniz.h"),
    person("Alex", "Evans",
        role = "cph",
        comment = "PNG writing code in miniz.h"),
    person("Sean", "Barrett",
        role = "cph",
        comment = "Author of stb_image.h"),
    person("Jorge L", "Rodriguez",
        role = "cph",
        comment = "Author of stb_image_resize.h"),
    person("Niels", "Lohmann",
        role = "cph",
        comment = "Author of json.hpp (nlohmann/json)"),
    person("Susumu", "Yata",
        role = "cph",
        comment = "Author of darts.h (darts-clone)"),
    person("Kuba", "Podgorski",
        role = "cph",
        comment = "Author of zip.h/zip.c (kuba--/zip)"),
    person("Meta Platforms Inc.",
        role = "cph",
        comment = "rng_mt19937.hpp (ported from PyTorch)"),
    person("Google Inc.",
        role = "cph",
        comment = "Sentencepiece tokenizer code in t5.hpp")
    )
Description: Provides Stable Diffusion image generation in R using the 'ggmlR'
    tensor library. Supports text-to-image and image-to-image generation with
    multiple model versions (SD 1.x, SD 2.x, 'SDXL', Flux). Implements the
    full inference pipeline including CLIP text encoding, 'UNet' noise removal,
    and 'VAE' encoding/decoding. Unified sd_generate() entry point with
    automatic strategy selection (direct, tiled sampling, high-resolution fix)
    based on output resolution and available 'VRAM'. High-resolution generation
    (2K, 4K+) via tiled 'VAE' decoding, tiled diffusion sampling
    ('MultiDiffusion'), and classic two-pass refinement (text-to-image, then
    upscale with image-to-image). Multi-GPU parallel generation via
    sd_generate_multi_gpu(). Multi-GPU model parallelism via 'device_layout'
    in sd_ctx(): distribute diffusion, text encoders, and 'VAE' across
    separate 'Vulkan' devices. Built-in profiling (sd_profile_start(),
    sd_profile_summary()) for per-stage timing of text encoding, sampling,
    and 'VAE' decode. Interactive Shiny GUI via sd_app() with non-blocking
    asynchronous generation (C++ std::thread), live progress bar, auto-detection
    of model architecture, and ETA display. Supports CPU and 'Vulkan' GPU.
    No 'Python' or external API dependencies required.
    Cross-platform: Linux, macOS, Windows.
SystemRequirements: GNU make, curl or wget (for downloading vocabulary
        files during installation)
License: MIT + file LICENSE
URL: https://github.com/Zabis13/sd2R
BugReports: https://github.com/Zabis13/sd2R/issues
Depends: R (>= 4.1.0)
Encoding: UTF-8
Imports: Rcpp (>= 1.0.0), ggmlR (>= 0.5.0)
LinkingTo: Rcpp, ggmlR
Suggests: testthat (>= 3.0.0), callr, png, shiny, base64enc, plumber,
        jsonlite
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: yes
Packaged: 2026-04-08 18:39:17 UTC; yuri
Author: Yuri Baramykov [aut, cre],
  Georgi Gerganov [ctb, cph] (Author of the GGML library),
  leejet [ctb, cph] (Author of stable-diffusion.cpp),
  stduhpf [ctb] (Core contributor to stable-diffusion.cpp),
  Green-Sky [ctb] (Contributor to stable-diffusion.cpp),
  wbruna [ctb] (Contributor to stable-diffusion.cpp),
  akleine [ctb] (Contributor to stable-diffusion.cpp),
  Martin Raiber [cph] (Copyright holder in miniz.h),
  Rich Geldreich [cph] (Author of miniz.h),
  RAD Game Tools [cph] (Copyright holder in miniz.h),
  Valve Software [cph] (Copyright holder in miniz.h),
  Alex Evans [cph] (PNG writing code in miniz.h),
  Sean Barrett [cph] (Author of stb_image.h),
  Jorge L Rodriguez [cph] (Author of stb_image_resize.h),
  Niels Lohmann [cph] (Author of json.hpp (nlohmann/json)),
  Susumu Yata [cph] (Author of darts.h (darts-clone)),
  Kuba Podgorski [cph] (Author of zip.h/zip.c (kuba--/zip)),
  Meta Platforms Inc. [cph] (rng_mt19937.hpp (ported from PyTorch)),
  Google Inc. [cph] (Sentencepiece tokenizer code in t5.hpp)
Maintainer: Yuri Baramykov <lbsbmsu@mail.ru>
Repository: CRAN
Date/Publication: 2026-04-09 12:00:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-04-09 14:28:36 UTC; unix
Archs: sd2R.so.dSYM
