# Generated by roxygen2: do not edit by hand

S3method(print,sd_node)
S3method(print,sd_pipeline)
S3method(print,sd_profile)
S3method(print,sd_system_info)
export(LORA_APPLY_MODE)
export(PREDICTION)
export(RNG_TYPE)
export(SAMPLE_METHOD)
export(SCHEDULER)
export(SD_CACHE_MODE)
export(SD_TYPE)
export(sd_api_start)
export(sd_api_stop)
export(sd_app)
export(sd_cache_params)
export(sd_convert)
export(sd_ctx)
export(sd_generate)
export(sd_generate_multi_gpu)
export(sd_image_to_array)
export(sd_img2img)
export(sd_list_models)
export(sd_load_image)
export(sd_load_model)
export(sd_load_pipeline)
export(sd_node)
export(sd_pipeline)
export(sd_profile_get)
export(sd_profile_start)
export(sd_profile_stop)
export(sd_profile_summary)
export(sd_register_model)
export(sd_remove_model)
export(sd_run_pipeline)
export(sd_save_image)
export(sd_save_pipeline)
export(sd_scan_models)
export(sd_system_info)
export(sd_txt2img)
export(sd_txt2img_highres)
export(sd_txt2img_tiled)
export(sd_unload_all)
export(sd_unload_model)
export(sd_upscale_image)
export(sd_vulkan_device_count)
importFrom(Rcpp,sourceCpp)
importFrom(utils,modifyList)
importFrom(utils,tail)
useDynLib(sd2R, .registration = TRUE)
